@@ -31,7 +31,7 @@ def secret_out(t, ns, res, output, show_type):
         row.append(data)
         # age
         try:
-            ct = sec['metadata']['creationTimestamp']
+            ct = str(sec['metadata']['creationTimestamp'])
             ts = r['gen_ts']
             row.append(age(ct,ts))
         except:
